@@ -11,6 +11,18 @@
 @CREATED    : May 13, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: minccopy.c,v $
+ * Revision 6.6  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.5  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.4  2007/12/11 12:43:01  rotor
+ *  * added static to all global variables in main programs to avoid linking
+ *       problems with libraries (compress in mincconvert and libz for example)
+ *
  * Revision 6.3  2006/05/19 00:35:58  bert
  * Add config.h to several files that might need it
  *
@@ -56,10 +68,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/minccopy/minccopy.c,v 6.3 2006/05/19 00:35:58 bert Exp $";
-#endif
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -77,7 +85,7 @@ static char rcsid[]="$Header: /private-cvsroot/minc/progs/minccopy/minccopy.c,v
 #endif
 
 /* Variables used for argument parsing */
-int copy_pixel_values = FALSE;
+static int copy_pixel_values = FALSE;
 
 /* Argument table */
 ArgvInfo argTable[] = {
