@@ -12,10 +12,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Prog_utils/arrays.c,v 1.4 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 #include  <internal_volume_io.h>
 
 /* ----------------------------- MNI Header -----------------------------------
