@@ -15,10 +15,6 @@
 #include  <internal_volume_io.h>
 #include  <minc.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/output_mnc.c,v 1.60 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 #define  INVALID_AXIS   -1
 
 #define  MIN_SLAB_SIZE   10000      /* at least 10000 entries per read */
